/pidgin/main: 7fab4043641f: Imgupload: rename to Image Uploader

Tomasz Wasilczyk twasilczyk at pidgin.im
Tue May 20 17:06:01 EDT 2014


Changeset: 7fab4043641f36b06c70ecaa4dfb5574ecf9ad21
Author:	 Tomasz Wasilczyk <twasilczyk at pidgin.im>
Date:	 2014-05-20 23:05 +0200
Branch:	 default
URL: https://hg.pidgin.im/pidgin/main/rev/7fab4043641f

Description:

Imgupload: rename to Image Uploader

diffstat:

 pidgin/plugins/imgupload.c |  6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diffs (28 lines):

diff --git a/pidgin/plugins/imgupload.c b/pidgin/plugins/imgupload.c
--- a/pidgin/plugins/imgupload.c
+++ b/pidgin/plugins/imgupload.c
@@ -1,5 +1,5 @@
 /*
  * Image Upload - an inline images implementation for protocols without
  * support for such feature.
  *
  * Copyright (C) 2014, Tomasz Wasilczyk <twasilczyk at pidgin.im>
@@ -420,7 +420,7 @@ imgup_prefs_get(PurplePlugin *plugin)
 	purple_request_cpar_set_icon(cpar, PURPLE_REQUEST_ICON_DIALOG);
 
 	handle = purple_request_fields(plugin,
-		_("Image Upload"), NULL, NULL, fields,
+		_("Image Uploader"), NULL, NULL, fields,
 		_("OK"), (GCallback)imgup_prefs_ok,
 		_("Cancel"), NULL,
 		cpar, NULL);
@@ -451,7 +451,7 @@ static PurplePluginInfo imgup_info =
 	NULL,
 	PURPLE_PRIORITY_DEFAULT,
 	"gtk-imgupload",
-	N_("Image Upload"),
+	N_("Image Uploader"),
 	DISPLAY_VERSION,
 	N_("Inline images implementation for protocols without such feature."),
 	N_("Adds inline images support for protocols lacking this feature by "
@@ -1,5 +1,5 @@
 /*
- * Image Upload - an inline images implementation for protocols without
+ * Image Uploader - an inline images implementation for protocols without
  * support for such feature.
  *



More information about the Commits mailing list